
package TestApp::Model::Repl;

use strict;
use warnings;

use base qw/Catalyst::Model::MozRepl/;

# __PACKAGE__->config();

=head1 NAME

TestApp::Model::Repl - Catalyst model to access mozilla using by MozRepl.

=head1 SYNOPSIS

SEE L<TestApp>

=head1 DESCRIPTION

See L<Catalyst::Model::MozRepl>, L<MozRepl>

=head1 AUTHOR

Toru Yamaguchi

=head1 LICENSE

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1;
