use Test::More tests => 2;

BEGIN {
    use_ok('Catalyst::Helper::Model::MozRepl');
    use_ok('Catalyst::Model::MozRepl');
}

diag( "Testing Catalyst::Helper::Model::MozRepl $Catalyst::Helper::Model::MozRepl::VERSION" );
